ManagerChain

Trait ManagerChain 

pub trait ManagerChain<'c, S>
where S: Socket,
{ // Required method fn describe(self) -> Result<Chain<'c, S>>; }
Extension trait for adding proxy calls to any chain.

This trait provides methods to add proxy calls to a chain of method calls.

Required Methods

fn describe(self) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'c, S> ManagerChain<'c, S> for Chain<'c, S>
where S: Socket,

Source

fn describe(self) -> Result<Chain<'c, S>>

Implementors